require 'uu/os/application/config'

module UU
  module OS
    module CMD
      # Load configuration file from ./config folder and merge it with server context.
      class AppConfigLoader
        
        # Name of folder in app root
        #
        # @private
        CONFIG_FOLDER = 'config' # :nodoc:
        
        # Config file name
        #
        # @private
        CONFIG_FILE_NAME = 'app.rb' # :nodoc:
        
        def self.on_server_startup(ctx)
          # load config 
          load_config(ctx)
          # merge with server context where parameters envinronment and 
          # uu-client.properties are.
          UU::OS::Application::Config.merge!(ctx.configuration)
          UU::OS::Application::Config.reload
        end
        
        # Load configuration from ./config/app.rb file
        # @return [void]
        def self.load_config(ctx)
          path = get_config_file(ctx)
          # disable dynamic reloaing
          UU::OS::Application::Config.class_variable_set(:@@reload_disabled, true)
          # use load instead of require because if we start server multiple times in one 
          # runtime (e.g. in tests) we need to load config every time 
          load path if File.exist? path
          # enable dynamic reloaing
          UU::OS::Application::Config.class_variable_set(:@@reload_disabled, false)
        end
        
        # Returns path to config file
        #
        # @return [void] String Path to file
        def self.get_config_file(ctx)
          # get app root
          root_dir = ctx.app_root_dir
          # concat path
          path = File.join(root_dir, CONFIG_FOLDER, CONFIG_FILE_NAME)
        end
        
      end
    end
  end
end